;!function(){try{var k="_btDebugIds",u="undefined",v="0a3aef6b-1694-5fd7-e38f-095d1475078e",a=function(x){try{x[k]=x[k]||{};x[k][n]=v}catch{}},n=(new Error).stack;n&&(u!=typeof window?a(window):u);n&&(u!=typeof global?a(global):u);n&&(u!=typeof self?a(self):u);n&&(u!=typeof globalThis?a(globalThis):u)}catch{}}();
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const backtrace_service_1 = require("backtrace-service");
const path_1 = require("path");
const archive_1 = require("../lib/archive");
const errors_1 = require("../lib/errors");
const util_1 = require("../lib/util");
const log = backtrace_service_1.Logger.getLogger();
const archivesController = (db, service, urlPrefix) => {
    service.app.delete(`${urlPrefix}/:universeName/:projectName/archives/:id`, service.identityManager.authenticateRequest(), (0, util_1.accessCheck)(service), (0, util_1.adminCheck)(service), (0, backtrace_service_1.asyncWrapper)(async (req, res, _next) => {
        const { projectName, universeName, id } = req.params;
        const repo = await db("repositories").first("*").where({
            universe_name: universeName,
            project_name: projectName,
            id,
        });
        if (!repo) {
            return res
                .status(404)
                .send((0, errors_1.getError)(5, `Repository with id ${id} not found`));
        }
        await (0, archive_1.deleteArchive)(parseInt(id, 10));
        return res.status(200).send();
    }));
    service.app.post(`${urlPrefix}/:universeName/:projectName/archives`, service.identityManager.authenticateRequest(), (0, util_1.accessCheck)(service), (0, util_1.adminCheck)(service), (0, backtrace_service_1.asyncWrapper)(async (req, res, _next) => {
        const { universeName, projectName } = req.params;
        const { name, default_commit } = req.body;
        const { archive } = await (0, archive_1.createArchive)({
            universe_name: universeName,
            project_name: projectName,
            name,
            default_commit,
        });
        res.json({ archive });
    }));
    service.app.put(`${urlPrefix}/:universeName/:projectName/archives/:id`, service.identityManager.authenticateRequest(), (0, util_1.accessCheck)(service), (0, util_1.adminCheck)(service), (0, backtrace_service_1.asyncWrapper)(async (req, res, _next) => {
        const { projectName, universeName, id } = req.params;
        const repo = await db("repositories").first("*").where({
            universe_name: universeName,
            project_name: projectName,
            id,
        });
        if (!repo) {
            return res
                .status(404)
                .send((0, errors_1.getError)(5, `Repository with id ${id} not found`));
        }
        const updateProps = {};
        const { name, default_commit, commit_rules } = req.body;
        if (name && name.trim() !== "") {
            updateProps.name = name.trim();
        }
        if (default_commit && default_commit.trim() !== "") {
            updateProps.default_commit = default_commit.trim();
        }
        await db("repositories").where("id", id).update(updateProps);
        if (commit_rules &&
            Array.isArray(commit_rules) &&
            commit_rules.length > 0) {
            const trimmed = commit_rules
                .map((cr) => cr.trim())
                .filter((cr) => cr.length > 0);
            if (trimmed.length > 0) {
                await db("commit_rules").where({ repository_id: id }).del();
                trimmed.forEach(async (val, idx) => await db("commit_rules").insert({
                    repository_id: id,
                    position: idx,
                    attribute_template: val,
                }));
            }
        }
        const archive = await db("repositories").first("*").where("id", id);
        res.json({ archive });
    }));
    service.app.post(`${urlPrefix}/:universeName/:projectName/archives/:id/upload`, service.identityManager.authenticateRequest(), (0, backtrace_service_1.asyncWrapper)(async (req, res, _next) => {
        let { id, universeName, projectName } = req.params;
        if (!Number.isInteger(parseInt(id, 10))) {
            service.identityManager.bypassProjectAccessCheck(res);
            return res.status(422).send((0, errors_1.getError)(2, "Invalid ID"));
        }
        const arch = await db("repositories").first("*").where({
            id,
            universe_name: universeName,
            project_name: projectName,
        });
        service.identityManager.bypassProjectAccessCheck(res);
        if (!arch) {
            return res
                .status(404)
                .send((0, errors_1.getError)(18, `Archive with id ${id} not found`));
        }
        const { fields, files } = await (0, util_1.parseForm)(req);
        if (!fields.secret) {
            return res
                .status(404)
                .send((0, errors_1.getError)(20, "Secret not provided: must include secret in request."));
        }
        if (fields.secret !== arch.archive_secret) {
            return res
                .status(404)
                .send((0, errors_1.getError)(21, `Secret does not match the one on record for ${arch.name}.`));
        }
        const fileName = files.file.name;
        const filePath = files.file.path;
        const tag = fields.tag
            ? fields.tag
            : (0, path_1.basename)(fileName, (0, path_1.extname)(fileName));
        try {
            await (0, archive_1.addTarToArchive)(filePath, tag, parseInt(id, 10));
        }
        catch (e) {
            if (/tag .+ already exists/.test(e.message)) {
                return res
                    .status(400)
                    .send((0, errors_1.getError)(19, "This tag already exists"));
            }
            if (/does not look like a tar archive/.test(e.message)) {
                return res
                    .status(400)
                    .send((0, errors_1.getError)(22, "This does not look like an acceptable archive format"));
            }
            log.error(e);
            return res.status(400).send((0, errors_1.getError)(3));
        }
        return res.status(200).send();
    }));
};
exports.default = archivesController;
//# sourceMappingURL=archives.js.map
//# debugId=0a3aef6b-1694-5fd7-e38f-095d1475078e