;!function(){try{var k="_btDebugIds",u="undefined",v="8d573635-99db-bfb6-ecd0-bd97ea037b12",a=function(x){try{x[k]=x[k]||{};x[k][n]=v}catch{}},n=(new Error).stack;n&&(u!=typeof window?a(window):u);n&&(u!=typeof global?a(global):u);n&&(u!=typeof self?a(self):u);n&&(u!=typeof globalThis?a(globalThis):u)}catch{}}();
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const backtrace_service_1 = require("backtrace-service");
const errors_1 = require("../lib/errors");
const git_routines_1 = require("../lib/git_routines");
const git_stats_1 = require("../lib/git_stats");
const perforce_1 = require("../lib/perforce");
const search_logger_1 = __importDefault(require("../lib/search_logger"));
const util_1 = require("../lib/util");
const log = backtrace_service_1.Logger.getLogger();
const sourceCodeController = (db, service, urlPrefix) => {
    service.app.post(`${urlPrefix}/:universeName/:projectName/show`, service.identityManager.authenticateRequest(), (0, util_1.accessCheck)(service), (0, backtrace_service_1.asyncWrapper)(async (req, res, _next) => {
        const startTs = new Date();
        res.on("finish", function () {
            service.metrics.addMetricHistogram("total_request_latency", new Date().valueOf() - startTs.valueOf());
        });
        const attributes = req.body.attributes;
        const directory = req.body.directory;
        const fileName = req.body.fileName;
        const fullPath = `${directory}/${fileName}`;
        const faultingLine = req.body.faultingLine;
        const surroundingLines = req.body.surroundingLines;
        const functionName = req.body.functionName;
        const objectName = req.body.objectName;
        const includeBlame = req.body.includeBlame;
        const { projectName, universeName } = req.body;
        const searchLog = new search_logger_1.default();
        const stats = new git_stats_1.Stats({
            name: "git stats",
            res,
            init: {
                project: projectName,
                universe: universeName,
                search_params: {
                    directory,
                    fileName,
                    fullPath,
                    faultingLine,
                    surroundingLines,
                    functionName,
                    objectName,
                    includeBlame,
                },
            },
        });
        if (!fileName || fileName === "<compiler-generated>") {
            stats.merge({ filename_not_specified: 1, search_success: 0 });
            log.debug("No match: Filename not specified.");
            return res
                .status(404)
                .send((0, errors_1.getError)(0, "Not enough information to locate source code: Filename not specified."));
        }
        const obj = {
            fileName,
            fullPath,
            functionName,
            objectName,
            attributes,
        };
        try {
            await (0, util_1.withTimeout)((0, git_routines_1.cloneSubmodulesRecursivelyForProject)(db, universeName, projectName, obj, universeName, projectName), 5000);
        }
        catch (e) {
            log.error(e);
        }
        const matchingFile = await (0, git_routines_1.getMatchingFile)({
            universeName,
            projectName,
            obj,
            db,
            searchLog,
            stats,
        });
        if (matchingFile === null) {
            stats.setLatency("search_latency");
            stats.merge({ search_success: 0 });
            log.debug(`No match: universe ${universeName} project ${projectName} filepath ${obj.fullPath}`);
            const errorRsp = (0, errors_1.getError)(0);
            errorRsp.meta = { searchLog: searchLog.getAll() };
            service.metrics.addMetricHistogram("no_match_found", new Date().valueOf() - startTs.valueOf());
            return res.status(404).send(errorRsp);
        }
        else if ("repoId" in matchingFile) {
            stats.setLatency("search_latency");
            stats.merge({ search_success: 1, repo_type: "git" });
            const { repo, repoId, repoName, filePath, commitHash, commitDate, } = matchingFile;
            log.debug(`Found a match: repo ${repoId} filepath ${filePath} commit ${commitHash}`);
            const { fileContents, blame, timeStamps, commits, startLine, totalLines, } = await (0, git_routines_1.gitShow)({
                repo,
                repoId,
                commitHashUnsanitized: commitHash,
                filePathUnsanitized: filePath,
                faultingLine,
                surroundingLines,
                includeBlame,
                universeName,
                projectName,
            });
            const fileContentsHighlighted = await (0, util_1.highlightCodeCached)(universeName, projectName, fileContents, stats);
            service.metrics.addMetricHistogram("git_match_found", new Date().valueOf() - startTs.valueOf());
            return res.json({
                fileContents,
                fileContentsHighlighted,
                blame,
                timeStamps,
                commits,
                sourceCommit: commitHash,
                sourceCommitDate: commitDate,
                sourceRepo: repoName,
                sourceFilepath: filePath,
                startLine,
                totalLines,
            });
        }
        else if ("perforceServerName" in matchingFile) {
            stats.setLatency("search_latency");
            stats.merge({ search_success: 1, repo_type: "p4" });
            const { perforceServer, perforceServerName, perforceServerId, depotFilepath, fileRevision, changelistId, changelistDescription, changelistDate, } = matchingFile;
            log.debug(`Found a match: server ${perforceServerName} (${perforceServerId}) filepath ${depotFilepath} revision: ${fileRevision}`);
            const { changelistIds, blame, timestamps, fileContents, totalLines, } = await (0, perforce_1.p4Annotate)(depotFilepath, fileRevision, perforceServer);
            const fileContentsStr = fileContents.join("\n");
            const fileContentsHighlighted = await (0, util_1.highlightCodeCached)(universeName, projectName, fileContentsStr);
            service.metrics.addMetricHistogram("p4_match_found", new Date().valueOf() - startTs.valueOf());
            return res.json({
                fileContents: fileContentsStr,
                fileContentsHighlighted,
                blame: blame.join("\n"),
                timeStamps: timestamps.join("\n"),
                commits: changelistIds.join("\n"),
                sourceCommit: changelistId,
                sourceCommitDate: changelistDate,
                sourceRepo: perforceServerName,
                sourceFilepath: depotFilepath,
                startLine: 1,
                totalLines,
            });
        }
    }));
};
exports.default = sourceCodeController;
//# sourceMappingURL=source_code.js.map
//# debugId=8d573635-99db-bfb6-ecd0-bd97ea037b12