/*
 * *** Migrate data to new table with tasks/copy_repositories_over.js ***
 *
 * This re-creates the repositories table, dropping the unique constraint from name,
 * and adding a proper unique constraint on [universe, project, name].
 * It includes the position an default_commit columns, which were originally added by
 * separate migrations.
 * We also add a new column named "last_fetched" which will hold a timestamp of when we
 * last successfuly fetched this repo.
 *
 * *** Migrate data to new table with tasks/copy_repositories_over.js ***
 */
exports.up = function(knex) {
  return knex.schema.createTable('repositories', function(t) {
    t.increments('id')
      .unsigned()
      .primary()
      .defaultTo(1);
    t.integer('project_name').notNullable();
    t.integer('universe_name').notNullable();
    t.string('name').notNullable()
    t.string('url').notNullable();
    t.enu('auth_type', ['none', 'ssh_key', 'user_pass']).notNullable();
    t.string('user_name');
    t.string('password');
    t.text('ssh_private_key');
    t.text('ssh_public_key');
    t.enu('clone_status', ['in_progress', 'complete', 'error']).notNullable();
    t.text('clone_error');
    t.datetime('last_fetched');
    t.integer('position').unsigned().notNullable().defaultTo(0);
    t.string('default_commit').notNullable().defaultTo("master");
    t.timestamps(false, true);
    t.index(['universe_name', 'project_name']);
    t.unique(['universe_name', 'project_name', 'name']);
  });
};

exports.down = function(knex) {
  return knex.schema.dropTable('repositories');
};
