import { BacktraceClient, BreadcrumbsManager } from '@backtrace/node';
import winston from 'winston';
export interface ILoggerOptions {
    logLevel: string;
    stackTrace: boolean;
    newline: boolean;
    transports?: winston.transport[];
}
export declare class Logger {
    private readonly _backtraceBreadcrumb;
    static getLogger(): Logger;
    /**
     * overrides the default logger instance or set the existing one.
     * @param logger the logger instance.
     */
    static setLogger(logger: Logger): void;
    private _breadcrumbsManager?;
    private _backtraceClient?;
    private static _logger;
    private readonly transportLevel;
    private readonly options;
    private readonly winstonLogger;
    constructor(logLevel?: string, options?: Partial<ILoggerOptions>);
    constructor(options?: Partial<ILoggerOptions>);
    /**
     * Sets up logging errors via Backtrace client
     * @param client Backtrace client
     */
    useBacktrace(client: BacktraceClient): Logger;
    /**
     * Sets up the breadcrumb integration in the Backtrace client
     * @param breadcrumbsManager breadcrumbs manager
     */
    useBreadcrumbsIntegration(breadcrumbsManager: BreadcrumbsManager): Logger;
    /**
     * Dispose the client
     */
    disposeClient(): void;
    trace(error: Error, data?: any, ...args: any[]): void;
    trace(data: any, ...args: any[]): void;
    info(error: Error, data?: any, ...args: any[]): void;
    info(data: any, ...args: any[]): void;
    warn(error: Error, data?: any, ...args: any[]): void;
    warn(data: any, ...args: any[]): void;
    debug(error: Error, data?: any, ...args: any[]): void;
    debug(data: any, ...args: any[]): void;
    error(error: Error, data?: any, ...args: any[]): void;
    error(error: Error, attributes: object, data?: any, ...args: any[]): void;
    error(data: any, ...args: any[]): void;
    error(data: any, attributes: object, ...args: any[]): void;
    log(level: string, error: Error, data?: any, ...args: any[]): void;
    log(level: string, data: any, ...args: any[]): void;
    private getTransportLevel;
    private defaultOptions;
}
