import express from 'express';
import { Logger } from '../log/logger';
export declare class MetricsStorage {
    private readonly uuid;
    private readonly secret;
    private opts?;
    private logger;
    readonly BIRTHDAY_METRIC = "birthday";
    /**
     * Service startup time
     */
    readonly BIRTHDAY: number;
    /**
     * Event fired before metrics send method. Please use this metod to add data from your
     * application metrics storage.
     */
    beforeSend?: () => Promise<void>;
    readonly enabled: boolean;
    private readonly _hostUrl;
    private _url;
    private readonly _defaultMetricsInterval;
    private readonly _hostName;
    /**
     * Metrics storage included in each metrics submission.
     * Metrics added here stays between beforeSend execution.
     */
    readonly data: Record<string, number>;
    private readonly _intervalId?;
    private _data;
    constructor(uuid: string, secret: string, opts?: {
        interval?: number | undefined;
        hostUrl?: string | undefined;
        disableExpressMetrics?: boolean | undefined;
    } | undefined, app?: express.Express, logger?: Logger);
    /**
     * Convert objects to metrics
     * @param source metrics object
     */
    add(source: object): void;
    /**
     * Add single value to metrics
     * @param name metrics name
     * @param value metrics value
     */
    addMetric(name: string, value: number): void;
    /**
     * Add single value to a histogram type metric
     * This is the same as addMetric except for _type: 'h'
     * @param name metrics name
     * @param value metrics value
     */
    addMetricHistogram(name: string, value: number): void;
    private registerRequestLatency;
    /**
     * Force metrics to be published to Circonus
     */
    send(): Promise<void>;
    destroy(): void;
}
