"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UniverseHelper = exports.validUniverseDomains = exports.http = exports.https = void 0;
exports.https = 'https://';
exports.http = 'http://';
// Any domains passed to a universe checking method
// should fail/return undefined if the domain isn't on this list
exports.validUniverseDomains = [
    '.backtrace.io',
    '.cloud-diagnostics.unity3d.com',
];
/**
 * Backtrae universe utils
 */
var UniverseHelper = /** @class */ (function () {
    function UniverseHelper() {
    }
    /**
     * return Backtrace host url
     * @param urlString sample url to any Backtrace resource
     * Example:
     * https://yolo.sp.backtrace.io => https://yolo.sp.backtrace.io
     * https://sampleHostName.backtrace.io/blah/poop/doop => https://sampleHostName.backtrace.io
     */
    UniverseHelper.getBacktraceHostName = function (urlString) {
        if (!urlString) {
            return undefined;
        }
        try {
            var url = new URL(urlString);
            return "".concat(url.protocol, "//").concat(url.hostname);
        }
        catch (_a) {
            return undefined;
        }
    };
    /**
     * Get an universe name from Backtrace url.
     * @param urlString sample url to any Backtrace resource
     * Example:
     * https://yolo.sp.backtrace.io => yolo
     * https://sampleHostName.backtrace.io => sampleHostName
     */
    UniverseHelper.getBacktaceUniverseName = function (urlString) {
        if (!urlString) {
            return undefined;
        }
        var urlObj = new URL(urlString);
        if (urlObj.hostname === 'submit.backtrace.io') {
            // https://submit.backtrace.io/yolo/hash/json
            // pathname is /yolo/hash/json
            return urlObj.pathname.split('/', 2)[1];
        }
        // Verify if the domain is valid
        if (exports.validUniverseDomains.every(function (domain) { return !urlObj.hostname.endsWith(domain); })) {
            return undefined;
        }
        return urlObj.hostname.split('.', 1)[0];
    };
    UniverseHelper.getBacktaceUniverseNameFromConf = function (conf) {
        var universeName = conf.universe.name;
        if (!universeName || conf.universe.deleted !== 0) {
            throw new Error('cannot find universe');
        }
        return universeName;
    };
    UniverseHelper.removeProtocol = function (str) {
        if (str.startsWith(exports.https)) {
            return str.substring(exports.https.length);
        }
        if (str.startsWith(exports.http)) {
            return str.substring(exports.http.length);
        }
        return str;
    };
    // Abstraction in case it needs to be extended in future
    UniverseHelper.normalizeUrl = function (str) {
        return this.removeProtocol(str);
    };
    return UniverseHelper;
}());
exports.UniverseHelper = UniverseHelper;
//# sourceMappingURL=backtraceUniverseHelper.js.map