/*
 * Update all repositories with proper positions, in order of their created_at dates
 * After running, do a sanity check with:
 * select universe_name, project_name, name, position from repositories ORDER BY universe_name, project_name, created_at;
 */

const knexfile = require("../knexfile");
const knex = require("knex");

let dbConfig;
if (process.env.NODE_ENV === "development") {
  dbConfig = knexfile.development;
} else {
  dbConfig = knexfile.production;
}
const db = knex(dbConfig);


(async () => {
  const repos = await db("repositories");
  let reposGroupedByProject = {}
  for(let repo of repos){
    reposGroupedByProject[repo.universe_name] = reposGroupedByProject[repo.universe_name] || {};
    reposGroupedByProject[repo.universe_name][repo.project_name] = reposGroupedByProject[repo.universe_name][repo.project_name] || [];
    reposGroupedByProject[repo.universe_name][repo.project_name].push(repo.id);
  }
  for(let universe in reposGroupedByProject){
    for(let project in reposGroupedByProject[universe]){
      let ids = reposGroupedByProject[universe][project];
      let reposInProject = await db("repositories")
        .select("id", "created_at")
        .whereIn("id", ids)
        .orderBy("created_at", "ASC");
      for(position in reposInProject){
        const id = reposInProject[position].id;
        await db("repositories")
          .where("id", id)
          .update({ position });
      }
    }
  }
  process.exit();
})();
