/* This task fetches a repository. Usage:
 *   NODE_ENV=development node dist/tasks/fetch_repo.js <REPO_ID>
 */
import db from "../src/lib/db";
import { newGit, gitFetch } from "../src/lib/git_routines";

const NODE_ENV = process.env.NODE_ENV;
if (NODE_ENV !== "production" && NODE_ENV !== "development") {
  console.error("Please set NODE_ENV to production or development");
  process.exit(-1);
}

const ID = process.argv[2];
if (ID === undefined) {
  console.error("Please provide a repository ID as the first argument.");
  process.exit(-1);
}

(async function () {
  const dbRepo = await db("repositories").first("*").where("id", ID);
  if (!dbRepo) throw new Error(`Repo ${ID} not found in database.`);
  const gitRepo = await newGit.getRepo(ID);
  await gitFetch(gitRepo, dbRepo, db);
  process.exit(0);
})();
