/*
 * Update all repo rules with proper positions, so there are no gaps.
 * After running, do a sanity check with:
 *   SELECT id, universe_name, project_name, matching_repository_id, position FROM rules ORDER BY universe_name, project_name, matching_repository_id, position;
 */

const knexfile = require("../knexfile");
const knex = require("knex");

let dbConfig;
if (process.env.NODE_ENV === "development") {
  dbConfig = knexfile.development;
} else {
  dbConfig = knexfile.production;
}
const db = knex(dbConfig);

/*
   Find all of the repo rules, group them by their parent repo, sort them by position, and re-number them contiguously
 */
(async () => {
  const rules = await db("rules");
  let rulesGroupedByRepo = {}
  for(let rule of rules){
    rulesGroupedByRepo[rule.universe_name] = rulesGroupedByRepo[rule.universe_name] || {};
    rulesGroupedByRepo[rule.universe_name][rule.project_name] = rulesGroupedByRepo[rule.universe_name][rule.project_name] || {};
    rulesGroupedByRepo[rule.universe_name][rule.project_name][rule.matching_repository_id] = rulesGroupedByRepo[rule.universe_name][rule.project_name][rule.matching_repository_id] || [];
    rulesGroupedByRepo[rule.universe_name][rule.project_name][rule.matching_repository_id].push(rule.id);
  }
  for(let universe in rulesGroupedByRepo){
    for(let project in rulesGroupedByRepo[universe]){
      for(let repoId in rulesGroupedByRepo[universe][project]){
        let ruleIds = rulesGroupedByRepo[universe][project][repoId];
        console.log("Updating:", universe, project, ruleIds);
        let rulesInRepo = await db("rules")
          .select("id", "position")
          .whereIn("id", ruleIds)
          .orderBy("position", "ASC");
        for(let index in rulesInRepo){
          const id = rulesInRepo[index].id;
          await db("rules")
            .where("id", id)
            .update({ position: index });
        }
      }
    }
  }
  process.exit();
})();
