"use strict";
import * as knexfile from "../../knexfile";
//import knex from "knex";
import db from "../../src/lib/db";
import * as fs from "fs";
import * as path from "path";
import * as rimraf from "rimraf";
import * as gitRoutines from "../../src/lib/git_routines";
import { ICrashObjData } from "../../src/lib/git_routines";
import DoNotUseList from "../../src/lib/do_not_use_list";

function cleanup() {
  try {
    // remove stale data
    rimraf.sync(path.resolve("test", "reposTmp"));
  } catch (e) {}
  try {
    fs.unlinkSync(knexfile.connection.filename);
  } catch (e) {}
}

beforeAll(async () => {
  cleanup();
  await db.migrate.latest();
});

afterAll(async () => {
  await db.destroy();
});

describe("perforce rules work correctly", () => {
  const universe_name = "testuniv",
    project_name = "testproj";
  async function serversSetup() {
    await db("perforce_servers").delete();
    await db("perforce_servers").insert({
      id: 1,
      universe_name,
      project_name,
      name: "server1",
      host: "localhost",
      port: 1666,
      user_name: "guest",
      connection_status: "working",
    });
    await db("perforce_servers").insert({
      id: 2,
      universe_name,
      project_name,
      name: "server2",
      host: "localhost",
      port: 1666,
      user_name: "guest",
      connection_status: "working",
    });
    await db("perforce_servers").insert({
      id: 3,
      universe_name,
      project_name,
      name: "server3",
      host: "localhost",
      port: 1666,
      user_name: "guest",
      connection_status: "working",
    });
  }
  test("evaluatePerforceRules -- no matching rules, get all servers", async () => {
    await serversSetup();
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 0,
      matching_perforce_id: 2,
      field_type: "function_name",
      field_name: "",
      regex: "bar",
      action: "full_stop",
    });
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 1,
      matching_perforce_id: 3,
      field_type: "function_name",
      field_name: "",
      regex: "foo",
      action: "match",
    });
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 2,
      matching_perforce_id: 1,
      field_type: "function_name",
      field_name: "",
      regex: "foo",
      action: "match_stop",
    });
    const rez = await gitRoutines.evaluatePerforceRules(
      universe_name,
      project_name,
      {} as ICrashObjData,
      db,
      new DoNotUseList()
    );
    expect(rez.length).toEqual(3);
  });
  test("evaluatePerforceRules -- full_stop means no results", async () => {
    await serversSetup();
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 0,
      matching_perforce_id: 3,
      field_type: "function_name",
      field_name: "",
      regex: "foo",
      action: "match",
    });
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 1,
      matching_perforce_id: 2,
      field_type: "function_name",
      field_name: "",
      regex: "bar",
      action: "full_stop",
    });
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 2,
      matching_perforce_id: 1,
      field_type: "function_name",
      field_name: "",
      regex: "foo",
      action: "match_stop",
    });
    const rez = await gitRoutines.evaluatePerforceRules(
      universe_name,
      project_name,
      { functionName: "bar" } as ICrashObjData,
      db,
      new DoNotUseList()
    );
    expect(rez).toEqual([]);
  });
  test("evaluatePerforceRules -- match_stop means only that one result", async () => {
    await serversSetup();
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 0,
      matching_perforce_id: 2,
      field_type: "function_name",
      field_name: "",
      regex: "bar",
      action: "full_stop",
    });
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 1,
      matching_perforce_id: 3,
      field_type: "function_name",
      field_name: "",
      regex: "foo",
      action: "match",
    });
    await db("perforce_rules").insert({
      universe_name,
      project_name,
      position: 2,
      matching_perforce_id: 1,
      field_type: "function_name",
      field_name: "",
      regex: "foo",
      action: "match_stop",
    });
    const rez = await gitRoutines.evaluatePerforceRules(
      universe_name,
      project_name,
      { functionName: "foo" } as ICrashObjData,
      db,
      new DoNotUseList()
    );
    expect(rez.length).toEqual(1);
    expect(rez[0].id).toEqual(1);
  });
});
